# rlx-helpers

Package containing utilities for working with the RLX data warehouse and other infrastructure, including helpers for service principal auth, Graph API client functions, interacting with Azure SQL databases using token auth and context managers, and ADLS data lake storage.
